@@ -18,7 +18,7 @@ sub DwwwInitialize($) {
     my $cfgvars  = ReadConfigFile($filename);
     my $dwwwvars = {};
 
-    map +{ $dwwwvars->{$_} = $cfgvars->{$_}->{'cfgval'} ? $cfgvars->{$_}->{'cfgval'}
+    map +{ $dwwwvars->{$_} = defined($cfgvars->{$_}->{'cfgval'}) ? $cfgvars->{$_}->{'cfgval'}
                                                        : $cfgvars->{$_}->{'defval'} }, keys %$cfgvars;
 
     umask (022);
