@@ -128,7 +128,7 @@ static const struct {/*{{{*/
         },
         {   U_BUG,
             "closes:",
-            "http://bugs.debian.org/",
+            "https://bugs.debian.org/",
             FL_MANY | FL_NOCASE,
             check_bug_uri
         },
@@ -150,15 +150,15 @@ static const struct {/*{{{*/
             0,
             check_mail_uri
         },
-        {   U_CVE, /* CVE-dddd-dddd*/
+        {   U_CVE, /* CVE-\d{4}-\d{4,7}*/
             "cve-",
-            "http://cve.mitre.org/cgi-bin/cvename.cgi?name=",
+            "https://cve.mitre.org/cgi-bin/cvename.cgi?name=",
             0,
             check_cve_uri
         },
-        {   U_CAN, /* CAN-dddd-dddd */
+        {   U_CAN, /* CAN-\d{4}-\d{4,7} */
             "can-",
-            "http://cve.mitre.org/cgi-bin/cvename.cgi?name=",
+            "https://cve.mitre.org/cgi-bin/cvename.cgi?name=",
             0,
             check_cve_uri
         }
@@ -470,7 +470,7 @@ static int txt2html(FILE *f UNUSED, char *filename UNUSED, void *dummy UNUSED) {
             break;
         case 0255: /* continuation hyphen */
             c = '-';
-            /* !!! NO BREAK !!! */
+            /* fall through */
         default:
             if (add(&data, &c, 1, flags) == -1)
                 return -1;
@@ -737,7 +737,7 @@ static int check_www_uri(char * buf, char * url, int uri_no, int loc, int * begi
                                 prefix = "ftp://";
                                 break;
                         }
-                        /* !!! NOBREAK !!! */
+                        /* fall through */
                 case U_HTTP:   /* "http" */
                         if (*tmp == 's')   tmp++;
                         if (*tmp++ != ':') return 0;
@@ -930,35 +930,32 @@ static int check_mail_uri(char * buf, char * url, int uri_no UNUSED, int loc, in
 static int check_cve_uri(char * buf, char * url, int uri_no UNUSED, int loc, int * begin, int * end)/*{{{*/
 {
 
-        int i, j;
+        int i;
         char * tmp;
         const int          isCVE   = (uris[uri_no].type == U_CVE);
         const char * const pattern = (isCVE ? "CVE-" : "CAN-");
         const size_t       patsize = 4;
 
         url[0] = '\0';
+        if (loc > 0 && isalnum(buf[loc-1]))
+            return 0;
+        if (strncmp(buf + loc, pattern, patsize))
+            return 0;
+        *begin = loc;
+        loc += patsize;
 
-        if (!strncmp(buf + loc, pattern, patsize))
+        /* check if buf[loc] =~ /\d{4}-\d{4,7}/
+         * i.e.  '0123-5678' up to '0123-5678999' */
+        for (i = 0; i < 4+1+7+1; ++i, ++loc)
         {
-            if (loc > 0 && isalnum(buf[loc-1]))
-                    return 0;
-            *begin = loc;
-            loc += patsize;
-        }
-        else
-        {
-                return 0;
-        }
+            if (i == 4 && buf[loc] == '-') /* 4th character needs to be '-' */
+                continue;
+            if (i != 4 && i != 12 && isdigit(buf[loc])) /* every character except for 4th and 12th can be a digit */
+                continue;
+            if (i > 8 && !isalnum(buf[loc])) /* characters 9th up to 12th can end the string */
+                break;
 
-        /* check if buf[loc] =~ /\d{4}-\d{4}/ */
-        for (j = 0; j < 2; j++) {
-            for (i = 0; i < 4; i++, loc++) {
-                    if (!(isdigit(buf[loc])))
-                            return 0;
-            }
-            if ((j == 0 && buf[loc++] != '-')
-               || (j == 1 && isalnum(buf[loc]) ) )
-                return 0;
+            return 0;
         }
 
         *end = loc - 1;
@@ -967,6 +964,5 @@ static int check_cve_uri(char * buf, char * url, int uri_no UNUSED, int loc, int
             *tmp++ = buf[i++];
         *tmp = 0;
 
-
         return 1;
 }/*}}}*/
